Index: Source/bindings/v8/V8LazyEventListener.cpp |
diff --git a/Source/bindings/v8/V8LazyEventListener.cpp b/Source/bindings/v8/V8LazyEventListener.cpp |
index 36383cb2477d86ad222af19b5ee2c92d627ab2ae..1d80ffd89bf48a68ca3abadbe462c0789c05fde7 100644 |
--- a/Source/bindings/v8/V8LazyEventListener.cpp |
+++ b/Source/bindings/v8/V8LazyEventListener.cpp |
@@ -136,7 +136,7 @@ void V8LazyEventListener::prepareListenerObject(ExecutionContext* context) |
// FIXME: Remove the following 'with' hack. |
// |
// Nodes other than the document object, when executing inline event |
// handlers push document, form, and the target node on the scope chain. |
// We do this by using 'with' statement. |
// See chrome/fast/forms/form-action.html |
// chrome/fast/forms/selected-index-value.html |
@@ -171,7 +171,7 @@ void V8LazyEventListener::prepareListenerObject(ExecutionContext* context) |
HTMLFormElement* formElement = 0; |
if (m_node && m_node->isHTMLElement()) |
- formElement = toHTMLElement(m_node)->form(); |
+ formElement = toHTMLElement(m_node)->formOwner(); |
v8::Handle<v8::Object> nodeWrapper = toObjectWrapper<Node>(m_node, isolate); |
v8::Handle<v8::Object> formWrapper = toObjectWrapper<HTMLFormElement>(formElement, isolate); |
@@ -136,7 +136,7 @@ void V8LazyEventListener::prepareListenerObject(ExecutionContext* context) |
// |
// Nodes other than the document object, when executing inline event |
- // handlers push document, form, and the target node on the scope chain. |
+ // handlers push document, form owner, and the target node on the scope chain. |
// We do this by using 'with' statement. |
// See chrome/fast/forms/form-action.html |